Package: rifiComparative
Title: 'rifiComparative' compares the output of rifi from two different
        conditions.
Version: 1.13.0
Authors@R: c(person("Loubna", "Youssar",
      email = "lyoussar@gmail.com",
      role = c("aut", "cre")),
      person("Jens", "Georg",
      email = "jens.georg@biologie.uni-freiburg.de",
      role = "aut", "cre"))
Description: 'rifiComparative' is a continuation of rifi package. It compares two conditions output of rifi using half-life and mRNA at time 0 segments. As an input for the segmentation, the difference between half-life of both condtions and log2FC of the mRNA at time 0 are used. The package provides segmentation, statistics, summary table, fragments visualization and some additional useful plots for further anaylsis. 
Depends: R (>= 4.2)
Imports: cowplot, doMC, parallel, dplyr, egg, foreach, ggplot2,
        ggrepel, graphics, grDevices, grid, methods, nnet, rlang,
        S4Vectors, scales, stats, stringr, tibble, rtracklayer, utils,
        writexl, DTA, LSD, reshape2, devtools, SummarizedExperiment
Suggests: DescTools, knitr, rmarkdown, BiocStyle
VignetteBuilder: knitr
biocViews: RNASeq, DifferentialExpression, GeneRegulation,
        Transcriptomics, Microarray, Software
BugReports: https://github.com/CyanolabFreiburg/rifiComparative
Config/Bioconductor/UnsupportedPlatforms: windows
License: GPL-3 + file LICENSE
Encoding: UTF-8
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.2.3
Language: en-US
git_url: https://git.bioconductor.org/packages/rifiComparative
git_branch: devel
git_last_commit: 19caa92
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-29 00:46:07 UTC; biocbuild
Author: Loubna Youssar [aut, cre],
  Jens cre Georg [aut]
Maintainer: Loubna Youssar <lyoussar@gmail.com>
