#' File for imported functions
#' 
#' 
#' @importFrom SummarizedExperiment rowRanges 
#' @importFrom scales alpha
#' @importFrom dplyr filter summarise mutate between full_join left_join
#' @importFrom ggrepel geom_text_repel
#' @importFrom LSD heatscatter
#' @importFrom ggplot2 ggplot
#' @importFrom cowplot background_grid
#' @importFrom reshape2 melt
#' @importFrom doMC registerDoMC
#' @importFrom foreach %dopar% foreach
#' @importFrom graphics abline axis curve legend par points text plot
#' @importFrom grDevices adjustcolor dev.off pdf pdf.options
#' @importFrom utils data
#' @importFrom grid arrow unit textGrob gpar
#' @importFrom stats na.omit nls p.adjust quantile residuals
#' @importFrom stats deviance t.test sd var
#' @importFrom parallel mclapply
#' @importFrom methods is
#' @importFrom rlang is_empty .data
#' @importFrom rtracklayer readGFF
#' @importFrom S4Vectors decode metadata
#' @importFrom stringr str_extract str_split
#' @importFrom tibble add_row
#' @importFrom nnet which.is.max
#' @noRd

# mutate_if left_join full_join last %>% group_by arrange n filter mutate
# right_join between

NULL
