utils::globalVariables(
        c(
                "intensity_comb_fragment",
                "cdt",
                ".",
                "synthesis_ratio",
                "label_log2_function",
                "label_square_function" ,
                "HL_comb_fragment" ,
                "distance_int" ,
                "png",
                "fc_sr" ,
                "fc_dr" ,
                "median" ,
                "HL_mean_fragment" ,
                "heatscatter" ,
                "value" ,
                "variable" ,
                "half_life.cdt1" ,
                "half_life.cdt2" ,
                "logFC_int" ,
                "P.Value" ,
                "annot_g" ,
                "indice" ,
                "position" ,
                "p_value_distance_intensity" ,
                "frag_HL" ,
                "frag_int" ,
                "synthesis_ratio",
                "distance_HL_log",
                "distance_HL",
                "p_value_distance_HL"
                )
)